'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

exports.default = function (_ref) {
	var t = _ref.types;

	var nameVisitor = {
		ExpressionStatement: function ExpressionStatement(path, _ref2) {
			var opts = _ref2.opts;

			var node = path.node;
			var expression = node.expression;

			if (t.isCallExpression(expression)) {
				var callee = expression.callee;

				if (t.isIdentifier(callee, { name: 'define' })) {
					var args = expression.arguments;

					var insertName = false,
					    unshiftName = true;

					switch (args.length) {
						case 1:
							insertName = t.isFunctionExpression(args[0]);
							break;

						case 2:
							insertName = t.isArrayExpression(args[0]) && t.isFunctionExpression(args[1]);
							break;

						case 3:
							unshiftName = false;
							insertName = t.isStringLiteral(args[0]) && t.isArrayExpression(args[1]) && t.isFunctionExpression(args[2]);
							break;
					}

					if (insertName) {
						var packageName = getPackageName(this.opts.packageName, this.filenameRelative);

						var moduleName = getModuleName(this.filenameRelative, getSrcPrefixes(opts));

						if (unshiftName) {
							args.unshift(t.stringLiteral('' + packageName + moduleName));
						} else {
							args[0].value = '' + packageName + moduleName;
						}

						path.stop();
					}
				}
			}
		}
	};

	return {
		visitor: {
			Program: {
				exit: function exit(path, state) {
					// We must traverse the AST again because the
					// transform-es2015-modules-amd plugin emits its define()
					// call after exiting Program node :-(
					path.traverse(nameVisitor, {
						filenameRelative: state.file.opts.filenameRelative,
						opts: state.opts
					});
				}
			}
		}
	};
};

var _liferayBuildToolsUtil = require('liferay-build-tools-util');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _readJsonSync = require('read-json-sync');

var _readJsonSync2 = _interopRequireDefault(_readJsonSync);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// TODO: check that module names are correct in Windoze

function getPackageName(packageName, filenameRelative) {
	packageName = packageName || '<package.json>';

	if (packageName === '<package.json>') {
		var pkgJsonPath = (0, _liferayBuildToolsUtil.getPackageJsonPath)(filenameRelative);
		var pkgJson = (0, _readJsonSync2.default)(pkgJsonPath);

		packageName = pkgJson.name + '@' + pkgJson.version + '/';
	}

	if (!packageName.endsWith('/')) {
		packageName += '/';
	}

	return packageName;
}

/**
 * options:
 *	  packageName: '<package.json>'
 *    srcPrefixes: ['src/main/resources/META-INF/resources']
 */


function getModuleName(filenameRelative, srcPrefixes) {
	var filenameAbsolute = _path2.default.resolve(filenameRelative);
	var pkgDir = (0, _liferayBuildToolsUtil.getPackageDir)(filenameRelative);

	var moduleName = filenameAbsolute.substring(pkgDir.length + 1);

	if (moduleName.toLowerCase().endsWith('.js')) {
		moduleName = moduleName.substring(0, moduleName.length - 3);
	}

	for (var i = 0; i < srcPrefixes.length; i++) {
		var srcPrefix = srcPrefixes[i];

		if (moduleName.startsWith(srcPrefix)) {
			moduleName = moduleName.substring(srcPrefix.length);
			break;
		}
	}

	return moduleName;
}

function getSrcPrefixes(opts) {
	var srcPrefixes = opts.srcPrefixes || ['src/main/resources/META-INF/resources'];

	return srcPrefixes.map(function (srcPrefix) {
		return srcPrefix.endsWith(_path2.default.sep) ? srcPrefix : srcPrefix + _path2.default.sep;
	});
}
//# sourceMappingURL=index.js.map